#-------------------------------------------------------------------------------
# @(#) common-modules/Example/EngineConfig.pm common-modules_r3.1.1.8:cset.001773:5:5 08/16/05 @(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# My Vendor Interface
# 
# Copyright (c) 2005 Vallent Software Systems UK. All rights reserved.

package EngineConfig;


@ISA = qw(Exporter);
@EXPORT = qw(engine_config);

#use diagnostics;
use strict;
use Exporter ();
use NAME_ID_MAPPING qw(load_name_id_config);

#-------------------------------------------------------------------------------


#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------
my %MONTH = (
    "01" => "Jan",
    "02" => "Feb",
    "03" => "Mar",
    "04" => "Apr",
    "05" => "May",
    "06" => "Jun",
    "07" => "Jul",
    "08" => "Aug",
    "09" => "Sep",
    "10" => "Oct",
    "11" => "Nov",
    "12" => "Dec"
);

my $name_id_config = &NAME_ID_MAPPING::load_name_id_config();
			 
my @rules = 
    (
     {
         RULE_TYPE => 'GENERIC_CSV_GATEWAY',
         RULE_DESC => 'Huawei MSC-S Interface',
         #INPUT_FILE_DESCRIPTION => [ '^pmresult_83888.*' ],
         INPUT_FILE_DESCRIPTION => [ '^pmresult_.*' ],
         #INPUT_DIR_DEPTH => 0,
         INPUT_DIR_DEPTH => 1,
         NUMBER_OF_FILES_TO_PROCESS => 10,
         ORDER_OF_FILES => 'OLDEST_FIRST',
	   	 FILENAME_HEADER_FIELDS     => {
	     	BLK_NAME => '^pmresult_(\d+)_\d+_\d+_\d+.csv$',
	 	 },
	 	 
	 FIELD_SEPARATOR            => ',',
         HEADERLINES_TO_SKIP        => 0,
         HEADER_FIELDS              => [0,1,3],
         DATA_FIELDS                => [2,4 .. 150],
         INVALID_VALUE_MATCH        => [],
         WHITESPACE_MODIFIER        => '_',
         FIELDS_TO_KEY_PIF_FILENAME => [],
         OUTPUT_BLOCK_NAME          => 'MSC',
         DEFAULT_NULL_VALUE         => '',
         UPPERCASE_COUNTERS         => 'True',
         
         HEADER_DATA_RECORD_PROCESSING => sub {
             my ($blk_name_ref, $h_ref, $d_ref) = @_;
            
	         return 1 if $h_ref->{'RESULT_TIME'} eq '';
	         return 1 if $d_ref->{'OBJECT_NAME'} eq '_';
             
             if ($h_ref->{'BLK_NAME'} != /^M\d+$/) {
	             $h_ref->{'BLK_NAME'} = 'M'.$h_ref->{'BLK_NAME'};
             }
             $$blk_name_ref = $h_ref->{'BLK_NAME'};
			
             if ( exists($h_ref->{'RESULT_TIME'}) ) {
	            my ($startdate, $starttime) = split(/\_/, $h_ref->{'RESULT_TIME'});
	            my ($year, $month, $day) = split(/\-/, $startdate);
                $startdate = $day.$MONTH{$month}.$year;
                $h_ref->{'START_DATE'} = $startdate;
                $h_ref->{'START_TIME'} = $starttime;
         	 } 
         	 
         	 if ( exists($h_ref->{'GRANULARITY_PERIOD'}) ) {
	         	 $h_ref->{'GP'} = $h_ref->{'GRANULARITY_PERIOD'};
	         	 delete $h_ref->{'GRANULARITY_PERIOD'};
         	 }
             
             foreach my $key (keys %{$d_ref}) {
	             if ($key =~ /^[\w+\W+]*$/) {
		             my $val = $d_ref->{$key};
		             delete $d_ref->{$key};
		             
		             $key =~ s/\_\(SECOND\)//g;
		             $key =~ s/\_\(TIMES\)//g;
		             $key =~ s/\_\(ITEM\)//g;
		             $key =~ s/\_\(LAST_RESULT\)//g;
		             $key =~ s/\_\(PCS\)//g;
		             $key =~ s/\_\(ERL\)//g;
		             $key =~ s/\_\(\%\)//g;
		             $key =~ s/[\(\)\"]//g;
		             $key =~ s/[\:\-\,]/\_/g;
		             $key =~ s/\__/\_/g;
		             
		             $key = substr($key, 0, length($key)-1) if substr($key, -1, 1) eq '_';
		             
		             $d_ref->{$key} = $val;
	             }
	             
	             my $obj_id;
	             if ($key eq 'OBJECT_NAME') {
		             my @obj_name1 = split('/', $d_ref->{$key});
		             $d_ref->{'MSC_Id'} = shift @obj_name1;
		 
		             my @obj_name2;
		             if (scalar(@obj_name1) > 1) {
		             	@obj_name2 = @obj_name1;
     	             } else {
	     	            @obj_name2 = split(/\,_/, $obj_name1[0]);
     	             }
		             
     	             my $flag = 0;
		             while (@obj_name2) {
			            my $obj2 = shift @obj_name2;
			            my ($counter, $value);
			            if ($obj2 =~ /[\,]/) {
				            $flag = 1;
				            my @obj_name3 = split(/\,_/, $obj2);
				            while (@obj_name3) {
					            my $obj3 = shift @obj_name3;
					            unshift(@obj_name2, $obj3);
				            }
				            next;
			            }
			            
			            if ($obj2 =~ /[\=]/) {
			             	($counter, $value) = split('=', $obj2, 2);  
			             	
		             	} elsif ($obj2 =~ /[\:]/) {
			             	($counter, $value) = split(':', $obj2, 2);  
		             	}
		             	$counter =~ s/\#//g;
			            $counter =~ s/\,/\-/g;
			            $counter =~ s/[\:\ \=]/\_/g;
			             
			            $value =~ s/\#//g;
			            $value =~ s/\,/\-/g;
			            $value =~ s/[\:\ \=]/\_/g;
			            
			            $d_ref->{uc($counter)} = $value;
      					
			            if ($obj_id eq '') {
				            $obj_id = $value;
			            } else {
				            if ($flag eq '1') {
					            if (scalar(@obj_name2) >= 1) {
						           $obj_id = $obj_id.'-'.$value; 
					            } else {
						           $obj_id = $obj_id.'/'.$value;   
					            }
						    } else {
			                	if (scalar(@obj_name1) > 1) {
					           		$obj_id = $obj_id.'/'.$value; 
				            	} else {
					           		$obj_id = $obj_id.'-'.$value; 
				            	}
			            	}
		                }
				        	 
				        $d_ref->{'OBJ_Id'} = $obj_id;
		             }
		             
		             delete $d_ref->{$key};
	             }
                
                 #Replace the counter name with counter id
	             if (exists $name_id_config->{$$blk_name_ref}->{$key}) {
		             my $counter_id = $name_id_config->{$$blk_name_ref}->{$key};
		             $d_ref->{$counter_id} = $d_ref->{$key};
		             delete $d_ref->{$key};
	             } 
             }
			 
             return 0;
             
         },


     },
);  


sub engine_config {
    return \@rules;
}

1;
