#-------------------------------------------------------------------------------
# Identifier for configuration management tool TrueChange
# @(#) generic-csv/parsersrc/NAME_ID_MAPPING.pm generic-csv_r3.1.0.2:cset.002093:15:15 01/03/07 @(#)
#-------------------------------------------------------------------------------
#
#   Entry Points:  New, load_config, process
#
#   This module map the FunctionSubSetID and Counter Name to return a Counter ID
#   
#   
#   Copyright (c) 2006 Vallent Software Systems UK. All rights reserved.
#
package NAME_ID_MAPPING;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

use AudLog;
use File::Basename;
use Text::ParseWords;

require Exporter;
require AutoLoader;
use GenUtils;

# generic module for conversion of date/time data
use Generic_Date_Handler;

@ISA = qw(Exporter AutoLoader);
# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.
@EXPORT = qw(load_name_id_config);

$VERSION = '0.01';

############################################################
#
# Sub: load_name_id_config
#
# Desc: This function loads Name_ID_Mapping.csv.
#
# Returns: a configuration hash reference 
#
############################################################
sub load_name_id_config {
	my $name_id_config = "Name_ID_Mapping.csv";
	        
	open(DAT, $name_id_config) || die("Could not open file $name_id_config!");
	my @lines=<DAT>;
	close(DAT);
	
	my %name_id_config = {};
	foreach my $line (@lines) {
		my ($blk_name, $ctr_id, $ctr_name) = split(/\,/, uc($line), 3);
		next if $ctr_name eq 'COUNTER NAME';
		chomp $ctr_name;
		$ctr_name =~ s/\_\(SECOND\)//g;
		$ctr_name =~ s/\_\(ITEM\)//g;
		$ctr_name =~ s/\_\(LAST_RESULT\)//g;
		$ctr_name =~ s/\_\(PCS\)//g;
		$ctr_name =~ s/\_\(ERL\)//g;
		$ctr_name =~ s/\_\(\%\)//g;
		$ctr_name =~ s/[\(\)\"]//g;
		$ctr_name =~ s/[\:\-\,\ ]/\_/g;
		$ctr_name =~ s/\__/\_/g;
			             
		defined $name_id_config{$blk_name} if ! exists $name_id_config{$blk_name};
		$name_id_config{$blk_name}{$ctr_name} = $ctr_id;
	}

	return \%name_id_config;
}

1;  # tells perl that the package is ready to run
